#
# spec file for package apache-commons-codec
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2010, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name  codec
%define short_name commons-%{base_name}
%bcond_with tests
Name:           apache-commons-codec
Version:        1.11
Release:        lp150.59.1
Summary:        Apache Commons Codec Package
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://commons.apache.org/codec/
Source0:        http://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        %{name}-build.xml
# Data in DoubleMetaphoneTest.java originally has an inadmissible license.
# The author gives MIT in e-mail communication.
Source100:      aspell-mail.txt
# PATCH-FIX-OPENSUSE Avoid spurious timeout in BeiderMorse tests
Patch0:         timeout.patch
BuildRequires:  ant
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
Requires:       java >= 1.8
Provides:       jakarta-%{short_name} = %{version}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       %{short_name} = %{version}
Obsoletes:      %{short_name} < %{version}
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit >= 1.7
BuildRequires:  apache-commons-lang3
BuildRequires:  hamcrest-core
BuildRequires:  junit
BuildRequires:  mozilla-nss
%endif

%description
Commons Codec is an attempt to provide definitive implementations of
commonly used encoders and decoders.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
Provides:       jakarta-%{short_name}-javadoc = %{version}
Obsoletes:      jakarta-%{short_name}-javadoc < %{version}
Provides:       %{short_name}-javadoc = %{version}
Obsoletes:      %{short_name}-javadoc < %{version}

%description    javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
cp %{SOURCE1} build.xml
cp %{SOURCE100} aspell-mail.txt
%patch0 -p1

#fixes eof encoding
dos2unix RELEASE-NOTES*.txt LICENSE.txt NOTICE.txt

%pom_remove_parent .

%build
mkdir -p lib
%if %{with tests}
build-jar-repository -s lib junit4 hamcrest/core commons-lang3
%endif
ant \
%if %{without tests}
  -Dtest.skip=true \
%endif
  -Dcompiler.source=1.8 -Dcompiler.target=1.8 \
  jar javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -sf %{short_name}.jar %{buildroot}%{_javadir}/%{name}.jar
# poms
# Install pom file
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -p -m 644 pom.xml %{buildroot}%{_mavenpomdir}/%{short_name}.pom
%add_maven_depmap %{short_name}.pom %{short_name}.jar -a "%{short_name}:%{short_name}"
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%pre javadoc
if [ -L %{_javadocdir}/%{name} ]; then
  rm -f %{_javadocdir}/%{name};
fi

%files -f .mfiles
%license LICENSE.txt
%doc RELEASE-NOTES.txt
%{_javadir}/%{name}.jar

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Remove pom parent, since we don't use it when not building with
  maven
* Fri Feb 15 2019 Fridrich Strba <fstrba@suse.com>
- Update to version 1.11
  * New features:
    + Add Automatic-Module-Name manifest entry for Java 9.
    Fixes CODEC-242.
    + Add BaseNCodec.encode(byte[], int, int) input with offset and
    length parameters for Base64 and Base32. Fixes CODEC-202.
    + Add convenience API org.apache.commons.codec.binary.Hex.
    .encodeHexString(byte[]|ByteBuffer, boolean).
    Fixes CODEC-224.
    + Add convenience method decodeHex(String). Fixes CODEC-203.
    + Add DigestUtils.getDigest(String, MessageDigest).
    Fixes CODEC-210.
    + Add faster CRC32 implementation. Fixes CODEC-205.
    + Add HmacAlgorithms.HMAC_SHA_224 (Java 8 only).
    Fixes CODEC-217.
    + Add java.io.File APIs to MessageDigestAlgorithm.
    Fixes CODEC-206.
    + Add support for CRC32-C. Fixes CODEC-171.
    + Add support for XXHash32. Fixes CODEC-241.
    + BaseNCodecOutputStream only supports writing EOF on close().
    Fixes CODEC-183.
    + Create a minimal Digest command line utility:
    org.apache.commons.codec.digest.Digest. Fixes CODEC-212.
    + Fluent interface for DigestUtils. Fixes CODEC-220.
    + Fluent interface for HmacUtils. Fixes CODEC-222.
    + Make some DigestUtils APIs public. Fixes CODEC-208.
    + Support java.nio.ByteBuffer in DigestUtils. Fixes CODEC-193.
    + Support java.nio.ByteBuffer in
    org.apache.commons.codec.binary.Hex. Fixes CODEC-194.
    + Support JEP 287: SHA-3 Hash Algorithms. Fixes CODEC-213.
    + Support SHA-224 in DigestUtils on Java 8. Fixes CODEC-195.
  * Removed feature:
    + Drop obsolete Ant build. Fixes CODEC-223.
  * Changes:
    + Base32.decode should support lowercase letters.
  Fixes CODEC-234.
    + HmacUtils.updateHmac calls reset() unnecessarily.
  Fixes CODEC-221.
    + Soundex should support more algorithm variants.
  Fixes CODEC-233.
  * Fixed bugs:
    + Base32.HEX_DECODE_TABLE contains the wrong value 32.
  Fixes CODEC-200.
    + Base64.encodeBase64String could better use newStringUsAscii
  (ditto encodeBase64URLSafeString). Fixes CODEC-145.
    + BaseNCodec: encodeToString and encodeAsString methods are
  identical. Fixes CODEC-144.
    + Bug in HW rule in Soundex. Fixes CODEC-199.
    + Charsets Javadoc breaks build when using Java 8.
  Fixes CODEC-207.
    + Don't deprecate Charsets Charset constants in favor of
  Java 7's java.nio.charset.StandardCharsets. Fixes CODEC-219.
    + Fix minor resource leaks. Fixes CODEC-225.
    + Javadoc for SHA-224 DigestUtils methods should mention
  Java 1.8.0 restriction instead of 1.4.0. Fixes CODEC-209.
    + StringUtils.equals(CharSequence cs1, CharSequence cs2) can
  fail with String Index OBE. Fixes CODEC-231.
    + StringUtils.newStringxxx(null) should return null, not NPE.
  Fixes CODEC-229.
    + URLCodec is neither immutable nor threadsafe.
  Fixes CODEC-232.
    + URLCodec.WWW_FORM_URL should be private. Fixes CODEC-230.
- Generate the Ant build file and use it
- Add an option --with tests and don't run tests by default. This
  diminshes the number of dependencies and speeds-up the build.
* Tue Feb  5 2019 Fridrich Strba <fstrba@suse.com>
- Clean-up the spec file
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
- Run fdupes on documentation
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Thu Sep  7 2017 fstrba@suse.com
- Build with java source and target versions 1.6
  * fixes build with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Dec  5 2014 p.drouand@gmail.com
- Update to version 1.10
  New features:
  + Add Daitch-Mokotoff Soundex
    Issue: CODEC-192.
  + QuotedPrintableCodec does not support soft line break per the
    'quoted-printable' example on Wikipedia
    Issue: CODEC-121.
  + Make possible to provide padding byte to BaseNCodec in constructor
    Issue: CODEC-181.
  Fixed Bugs:
  + Added clarification to Javadoc of Base64 concerning the use of the
    urlSafe parameter
    Issue: CODEC-185.
  + Added clarification to the Javadoc of Base[32|64]OutputStream that it
    is mandatory to call close()
    Issue: CODEC-191.
  + Add support for HMAC Message Authentication Code (MAC) digests
    Issue: CODEC-188.
  + Beider Morse Phonetic Matching producing incorrect tokens
    Issue: CODEC-187.
  + NullPointerException in DoubleMetaPhone.isDoubleMetaphoneEqual when
    using empty strings
    Issue: CODEC-184.
  + Fix Javadoc 1.8.0 errors
    Issue: CODEC-180.
  + Fix Java 8 build Javadoc errors
    Issue: CODEC-189.
  Changes:
  + Deprecate Charsets Charset constants in favor of Java 7's
    java.nio.charset.StandardCharsets
    Issue: CODEC-178.
  + Update from commons-parent 34 to 35
    Issue: CODEC-190.
- Use javapackages-tools instead of java-devel
- Remove gpg_verify usage; let obs handle it
* Mon Jul  7 2014 tchvatal@suse.com
- Set the bytecode properly on sle11
* Mon Jul  7 2014 tchvatal@suse.com
- Depend on junit not junit4.
* Sun Jun 22 2014 schwab@suse.de
- timeout.patch: avoid spurious timeout in BeiderMorse tests
* Thu May 15 2014 darin@darins.net
- disable bytecode check on sle_11
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Aug 26 2013 mvyskocil@suse.com
- update to 1.8
  * Add DigestUtils.updateDigest(MessageDigest, InputStream). Thanks to Daniel Cassidy.
  * Add JUnit to test our decode with pad character in the middle.
  * Add Match Rating Approach (MRA) phonetic algorithm encoder. Thanks to crice.
  * ColognePhonetic encoder unnecessarily creates many char arrays on every loop run. Thanks to leo141.
  * Base64.encodeBase64URLSafeString doesn't add padding characters at the end.
- temporary add mozilla-nss to BR: to pass tests
- drop unecessary source files
- add signature verification
- use newer add_maven_depmap
- fix source urls
* Mon Apr  2 2012 mvyskocil@suse.cz
- add junit4 to fix a build fail
* Tue Feb 28 2012 mvyskocil@suse.cz
- update to 1.6, sync with Fedora
* Fri Sep 22 2006 skh@suse.de
- don't use icecream
- use target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 dbornkessel@suse.de
- Current version 1.3 from JPackage.org
